@@ -19,7 +19,7 @@ from QuantLib import *
 todaysDate = Date(15,5,1998)
 Settings.instance().evaluationDate = todaysDate
 settlementDate = Date(17,5,1998)
-riskFreeRate = FlatForward(settlementDate, 0.06, Actual365())
+riskFreeRate = FlatForward(settlementDate, 0.06, Actual365Fixed())
 
 # option parameters
 exercise = AmericanExercise(settlementDate, Date(17,5,1999))
@@ -27,8 +27,8 @@ payoff = PlainVanillaPayoff('put', 40.0)
 
 # market data
 underlying = SimpleQuote(36.0)
-volatility = BlackConstantVol(todaysDate, 0.20)
-dividendYield = FlatForward(settlementDate, 0.00, Actual365())
+volatility = BlackConstantVol(todaysDate, 0.20, Actual365Fixed())
+dividendYield = FlatForward(settlementDate, 0.00, Actual365Fixed())
 
 # report
 header = '%19s' % 'method' + ' |' + \
@@ -60,6 +60,7 @@ process = BlackScholesProcess(QuoteHandle(underlying),
 option = VanillaOption(process, payoff, exercise)
 
 refValue = 4.48667344
+report('reference value',refValue)
 
 # method: analytic
 
@@ -69,6 +70,13 @@ report('Barone-Adesi-Whaley',option.NPV())
 option.setPricingEngine(BjerksundStenslandEngine())
 report('Bjerksund-Stensland',option.NPV())
 
+# method: finite differences
+timeSteps = 801
+gridPoints = 800
+
+option.setPricingEngine(FDAmericanEngine(timeSteps,gridPoints))
+report('finite differences',option.NPV())
+
 # method: binomial
 timeSteps = 801
 
